@@ -187,8 +187,7 @@ class JsonFormatter(logging.Formatter):
                         raise TypeError('`%s` is not callable.' % func)
 
                     if inspect.isfunction(func):
-                        argspec = getattr(inspect, 'getfullargspec',
-                                          inspect.getargspec)(func)
+                        argspec = (getattr(inspect, 'getfullargspec', None) or inspect.getargspec)(func)
                         if argspec.args:
                             raise TypeError(
                                 "`%s` must no Positional Parameters." % func.__name__
@@ -321,7 +320,7 @@ class JsonFormatter(logging.Formatter):
             record.message = str(record.msg)
 
         if record.args:
-            record.message = str(record.message) % record.args
+            record.message = record.getMessage()
 
         if record.exc_info:
             # Cache the traceback text to avoid converting it multiple times
@@ -382,7 +381,7 @@ class JsonFormatter(logging.Formatter):
         record.asctime = self.formatTime(record, self.datefmt)
 
         # pop stored __extra start
-        extra = record.__dict__.pop('__extra', None)
+        extra = record.__dict__.pop('__extra', None) or record.__dict__.pop('_JsonFormatter__extra', None)
         if extra is None:
             # extra is dictionary
             extra = self.getRecordExtraAttrs(record)
